const path = require("path");
const webpack = require("webpack");
const BundleAnalyzerPlugin = require("webpack-bundle-analyzer")
  .BundleAnalyzerPlugin;

const config = {
  entry: {
    footer: "./src/containers/Footer",
    form: "./src/components/Form",
    index: "./src",
    modal: "./src/components/Modal",
  },

  output: {
    path: path.resolve(process.cwd(), "dist"),
    filename: "[name].js",
    library: "nested",
    libraryTarget: "commonjs2",
  },

  externals: {
    react: "react",
    "react-dom": "react-dom",
    recompose: "recompose",
    "styled-components": "styled-components",
  },

  module: {
    rules: [
      {
        test: /\.js$/,
        use: "babel-loader",
        exclude: /node_modules/,
      },
      {
        test: /\.(woff|woff2)$/,
        use: "file-loader",
        exclude: /node_modules/,
      },
    ],
  },

  plugins: [
    new webpack.DefinePlugin({
      "process.env": {
        NODE_ENV: JSON.stringify(process.env.NODE_ENV),
      },
    }),
  ],

  resolve: {
    // directories where to look for modules
    modules: [path.resolve(process.cwd(), "src"), "node_modules"],
    extensions: [".js"],
  },
};

if (process.env.ANALYZE) {
  config.plugins.unshift(new BundleAnalyzerPlugin());
}

module.exports = config;
